@@ -26,8 +26,6 @@ def generate(ctx, repo_name, package_name, template):
     ctx.obj["helper"].generate(repo_name, package_name, template) 
 
 @cli.command()
-@click.option('--no-input', type=bool, is_flag=True,
-              help='Enables the absence of CLI prompts during pipeline run .', default=False)
 @click.option('--mode',type=click.Choice(['build', 'deploy','destroy'], case_sensitive=False))
 @click.option('--repo',type=str, help='Enter repo name')
 
@@ -37,10 +35,9 @@ def run_pipeline(ctx, mode, repo):
     ctx.obj["helper"].run_pipeline(mode,repo) 
 
 @cli.command()
-@click.option('--no-input', type=bool, is_flag=True,
-              help='Enables the absence of CLI prompts during pipeline check.', default=False)
 @click.option('--id',type=int, help='Enter pipeline id')
+@click.option('--pdf', type=bool, is_flag=True, default=False)
 @click.pass_context
-def check_pipeline(ctx, id):
+def check_pipeline(ctx, id, pdf):
     """Check the status of a pipeline"""
-    ctx.obj["helper"].check_pipeline(id)
+    ctx.obj["helper"].check_pipeline(id, pdf)
